Type Alias FxHashMap
type FxHashMap = HashMap<K, V, FxBuildHasher>
Type alias for a hash map that uses the Fx hashing algorithm.
FxHashMaptype FxHashMap = HashMap<K, V, FxBuildHasher>
Type alias for a hash map that uses the Fx hashing algorithm.