Type Alias FxHashMapSeed
type FxHashMapSeed = HashMap<K, V, FxSeededState>
Type alias for a hashmap using the fx hash algorithm with FxSeededState.
FxHashMapSeedtype FxHashMapSeed = HashMap<K, V, FxSeededState>
Type alias for a hashmap using the fx hash algorithm with FxSeededState.